@@ -1,13 +1,10 @@
 #################################################################
 #                             NETWAG                            #
 #                        Network toolbox                        #
-#           Copyright(c) 1999-2006 Laurent Constantin           #
+#           Copyright(c) 1999-2008 Laurent Constantin           #
 #                             -----                             #
-#  Main server    : http://www.laurentconstantin.com/           #
-#  Backup servers : http://go.to/laurentconstantin/             #
-#                   http://laurentconstantin.est-la.com/        #
-#                   http://laurentconstantin.free.fr/           #
-#                   http://membres.lycos.fr/lauconstantin/      #
+#  Main server   : http://www.laurentconstantin.com/            #
+#  Backup server : http://laurentconstantin.free.fr/            #
 #  [my current email address is on the web servers]             #
 #                             -----                             #
 #  This file is part of Netwag.                                 #
@@ -415,7 +412,7 @@ proc netwag_gui_notebook_infol { cf cb } {
   pack $cftt -side top -expand 1 -fill both
   pack $cf.text.left.xscro -side top -fill x
   eval "bind $cftt <Button-1> { focus $cftt }"
-  netwag_dynhelp_init $cftt "Local information depending of pressed button."
+  netwag_dynhelp_init $cftt "Local information depending on pressed button."
 
   netwag_dynhelp_init $cb "Display network configuration of the local computer."
 }
@@ -456,7 +453,7 @@ proc netwag_gui_notebook_infor { cf cb } {
   pack $cftt -side top -expand 1 -fill both
   pack $cf.text.left.xscro -side top -fill x
   eval "bind $cftt <Button-1> { focus $cftt }"
-  netwag_dynhelp_init $cftt "Local information depending of pressed button."
+  netwag_dynhelp_init $cftt "Information obtained about the hostname, IP address or Ethernet address."
 
   netwag_dynhelp_init $cb "Display network configuration of a remote computer."
 }
