@@ -1,13 +1,10 @@
 #################################################################
 #                             NETWAG                            #
 #                        Network toolbox                        #
-#           Copyright(c) 1999-2006 Laurent Constantin           #
+#           Copyright(c) 1999-2008 Laurent Constantin           #
 #                             -----                             #
-#  Main server    : http://www.laurentconstantin.com/           #
-#  Backup servers : http://go.to/laurentconstantin/             #
-#                   http://laurentconstantin.est-la.com/        #
-#                   http://laurentconstantin.free.fr/           #
-#                   http://membres.lycos.fr/lauconstantin/      #
+#  Main server   : http://www.laurentconstantin.com/            #
+#  Backup server : http://laurentconstantin.free.fr/            #
 #  [my current email address is on the web servers]             #
 #                             -----                             #
 #  This file is part of Netwag.                                 #
@@ -123,10 +120,7 @@ bxAPhxBMbBACgBACGdaBBsEGNqCDGnANlVcQAQEAOw==
   pack $hw.l2 -fill x
 
   set msg "\nhttp://www.laurentconstantin.com/\n"
-  append msg "http://go.to/laurentconstantin/\n"
-  append msg "http://laurentconstantin.est-la.com/\n"
   append msg "http://laurentconstantin.free.fr/\n"
-  append msg "http://membres.lycos.fr/lauconstantin/\n"
   label $hw.l3 -font myfont -bg $netwag_glo_gui_bgcolor_unused -text $msg -justify left
   pack $hw.l3 -fill both -expand 1
 
