@@ -1,13 +1,10 @@
 #################################################################
 #                             NETWAG                            #
 #                        Network toolbox                        #
-#           Copyright(c) 1999-2006 Laurent Constantin           #
+#           Copyright(c) 1999-2008 Laurent Constantin           #
 #                             -----                             #
-#  Main server    : http://www.laurentconstantin.com/           #
-#  Backup servers : http://go.to/laurentconstantin/             #
-#                   http://laurentconstantin.est-la.com/        #
-#                   http://laurentconstantin.free.fr/           #
-#                   http://membres.lycos.fr/lauconstantin/      #
+#  Main server   : http://www.laurentconstantin.com/            #
+#  Backup server : http://laurentconstantin.free.fr/            #
 #  [my current email address is on the web servers]             #
 #                             -----                             #
 #  This file is part of Netwag.                                 #
@@ -112,8 +109,8 @@ proc netwag_priv_toolrun_ctx_new { ctx buttontitle } {
   pack $netwag_priv_toolrun_widget($ctx,send).entry -side left -expand 1 -fill x -padx 2
   pack $netwag_priv_toolrun_widget($ctx,send).send $netwag_priv_toolrun_widget($ctx,send).echobut -side left
   netwag_dynhelp_init $netwag_priv_toolrun_widget($ctx,send).entry "Text to send to tool. Note : \"\\n\" indicates a new line."
-  netwag_dynhelp_init $netwag_priv_toolrun_widget($ctx,send).send "Send text is/isn't echoed."
-  netwag_dynhelp_init $netwag_priv_toolrun_widget($ctx,send).echobut "Send the text at the left to tool."
+  netwag_dynhelp_init $netwag_priv_toolrun_widget($ctx,send).send "Send the text (at the left) to tool."
+  netwag_dynhelp_init $netwag_priv_toolrun_widget($ctx,send).echobut "Send text is/isn't echoed."
   set netwag_priv_toolrun_widget($ctx,send_text) "\\n"
   set netwag_priv_toolrun_widget($ctx,send_echo) 1
 
