@@ -1,14 +1,11 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -59,12 +56,12 @@ static netwib_err netwib_debug_ring_check(netwib_conststring functionname,
   }
   netwib_er(netwib_buf_close(&errbuf));
   if (pcurrent->pnext != (netwib_ringitem *) pring) {
-    netwib_er(netwib_priv_errmsg_func_text(functionname,
+    netwib_er(netwib_priv_errmsg_func_string(functionname,
                                            "plast->pnext != pring"));
     return(NETWIB_ERR_LOINTERNALERROR);
   }
   if (pring->pprevious != pcurrent) {
-    netwib_er(netwib_priv_errmsg_func_text(functionname,
+    netwib_er(netwib_priv_errmsg_func_string(functionname,
                                            "pring->pprevious != plast"));
     return(NETWIB_ERR_LOINTERNALERROR);
   }
