@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -51,7 +51,7 @@
 netwib_err netwib_priv_libnet_notsupported(netwib_conststring msg);
 netwib_err netwib_priv_libnet_notsupported(netwib_conststring msg)
 {
-  netwib_er(netwib_priv_errmsg_text(msg));
+  netwib_er(netwib_priv_errmsg_string(msg));
   return(NETWIB_ERR_LONOTSUPPORTED);
 }
 
@@ -135,7 +135,7 @@ static netwib_err netwib_priv_libnet_init_link(netwib_conststring device,
   /* use cast because libnet prototype is not "const" */
   plli = libnet_open_link_interface(netwib_priv_caststring(device), errbuf);
   if (plli == NULL) {
-    netwib_er(netwib_priv_errmsg_text(errbuf));
+    netwib_er(netwib_priv_errmsg_string(errbuf));
     return(NETWIB_ERR_LONOTSUPPORTED);
   }
   plib->plli = plli;
@@ -239,7 +239,7 @@ static netwib_err netwib_priv_libnet_init_link(netwib_conststring device,
   plib->plibnett = libnet_init(LIBNET_LINK, netwib_priv_caststring(device),
                                errbuf);
   if (plib->plibnett == NULL) {
-    netwib_er(netwib_priv_errmsg_text(errbuf));
+    netwib_er(netwib_priv_errmsg_string(errbuf));
     return(NETWIB_ERR_FULIBNETINIT);
   }
   plib->fd = libnet_getfd((libnet_t*)plib->plibnett);
@@ -282,7 +282,7 @@ static netwib_err netwib_priv_libnet_init_ip4(netwib_priv_libnet *plib)
   char errbuf[LIBNET_ERRBUF_SIZE];
   plib->plibnett = libnet_init(LIBNET_RAW4, NULL, errbuf);
   if (plib->plibnett == NULL) {
-    netwib_er(netwib_priv_errmsg_text(errbuf));
+    netwib_er(netwib_priv_errmsg_string(errbuf));
     return(NETWIB_ERR_FULIBNETINIT);
   }
   plib->fd = libnet_getfd((libnet_t*)plib->plibnett);
@@ -321,7 +321,7 @@ static netwib_err netwib_priv_libnet_supports_ip6(netwib_bool *pyes)
   libnet_t *plibnett;
   plibnett = libnet_init(LIBNET_RAW6, NULL, errbuf);
   if (plibnett == NULL) {
-    netwib_er(netwib_priv_errmsg_text("libnet does not support raw IPv6"));
+    netwib_er(netwib_priv_errmsg_string("libnet does not support raw IPv6"));
     if (pyes != NULL) *pyes = NETWIB_FALSE;
   } else {
     libnet_destroy(plibnett);
@@ -334,7 +334,7 @@ static netwib_err netwib_priv_libnet_init_ip6(netwib_priv_libnet *plib)
   char errbuf[LIBNET_ERRBUF_SIZE];
   plib->plibnett = libnet_init(LIBNET_RAW6, NULL, errbuf);
   if (plib->plibnett == NULL) {
-    netwib_er(netwib_priv_errmsg_text(errbuf));
+    netwib_er(netwib_priv_errmsg_string(errbuf));
     return(NETWIB_ERR_FULIBNETINIT);
   }
   plib->fd = libnet_getfd((libnet_t*)plib->plibnett);
@@ -375,11 +375,11 @@ static netwib_err netwib_priv_libnet_supports_link(netwib_conststring device,
     if (hwtype == NETWIB_DEVICE_HWTYPE_ETHER) {
       if (pyes != NULL) *pyes = NETWIB_TRUE;
     } else {
-      netwib_er(netwib_priv_errmsg_text("device is not of Ethernet type"));
+      netwib_er(netwib_priv_errmsg_string("device is not of Ethernet type"));
       if (pyes != NULL) *pyes = NETWIB_FALSE;
     }
   } else {
-    netwib_er(netwib_priv_errmsg_text("WinPCAP >= 3.0 is not found"));
+    netwib_er(netwib_priv_errmsg_string("WinPCAP >= 3.0 is not found"));
     if (pyes != NULL) *pyes = NETWIB_FALSE;
   }
   device = device; /* for compiler warning */
@@ -439,7 +439,7 @@ static netwib_err netwib_priv_libnet_supports_ip4(netwib_bool *pyes)
 {
   netwib_windowstype windowstype;
   if (!netwib_global_dll_winsock2.isloaded) {
-    netwib_er(netwib_priv_errmsg_text("Winsock2 not found"));
+    netwib_er(netwib_priv_errmsg_string("Winsock2 not found"));
     if (pyes != NULL) *pyes = NETWIB_FALSE;
     return(NETWIB_ERR_OK);
   }
@@ -454,7 +454,7 @@ static netwib_err netwib_priv_libnet_supports_ip4(netwib_bool *pyes)
     case NETWIB_WINDOWSTYPE_NT350 :
     case NETWIB_WINDOWSTYPE_NT351 :
     case NETWIB_WINDOWSTYPE_NT4 :
-      netwib_er(netwib_priv_errmsg_text("Winsock2 version is too old"));
+      netwib_er(netwib_priv_errmsg_string("Winsock2 version is too old"));
       if (pyes != NULL) *pyes = NETWIB_FALSE;
       break;
     case NETWIB_WINDOWSTYPE_2000 :
