@@ -1,14 +1,11 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -73,7 +70,7 @@ netwib_err netwib_buf_append_icmp6type(netwib_icmp6type type,
       break;
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -219,7 +216,7 @@ netwib_err netwib_buf_append_icmp6code(netwib_icmp6type type,
     break;
   }
 
-  netwib_er(netwib_buf_append_text(pc, pbuf));
+  netwib_er(netwib_buf_append_string(pc, pbuf));
 
   return(NETWIB_ERR_OK);
 }
