@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -8,8 +8,8 @@ netwib_err netwib_priv_dir_create(netwib_constbuf *pdirname)
   netwib_bool errwin240;
   int reti;
 
-  netwib__buf_ref_string(pdirname, dirnamestr, bufstorage,
-                         netwib_priv_dir_create(&bufstorage));
+  netwib__constbuf_ref_string(pdirname, dirnamestr, bufstorage,
+                              netwib_priv_dir_create(&bufstorage));
 
   errwin240 = NETWIB_FALSE;
 #if defined NETWIBDEF_SYSNAME_Unix
@@ -26,12 +26,12 @@ netwib_err netwib_priv_dir_create(netwib_constbuf *pdirname)
 #endif
 
   if (reti == -1) {
-    netwib_er(netwib_priv_errmsg_text("cannot create this dir: "));
+    netwib_er(netwib_priv_errmsg_string("cannot create this dir: "));
     netwib_er(netwib_priv_errmsg_append_buf(pdirname));
 #if defined NETWIBDEF_SYSNAME_Unix
 #elif defined NETWIBDEF_SYSNAME_Windows
     if (errwin240) {
-      netwib_er(netwib_priv_errmsg_append_text(" (origin of this problem is perhaps Windows'limitation of 240 chars for total pathname length)"));
+      netwib_er(netwib_priv_errmsg_append_string(" (origin of this problem is perhaps Windows'limitation of 240 chars for total pathname length)"));
     }
 #else
 #error "Unknown value for NETWIBDEF_SYSNAME"
@@ -50,8 +50,7 @@ static netwib_err netwib_priv_dir_create_recur(netwib_constbuf *pdirname)
   netwib_bool yes;
   netwib_err ret;
 
-  netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &parent));
-  parent.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(array, &parent));
   ret = netwib_path_decode_parent(pdirname, &parent);
   if (ret == NETWIB_ERR_PAPATHCANTINIT) {
     /* can't go up, we will directly create directory */
@@ -80,9 +79,7 @@ netwib_err netwib_priv_dir_create_parents(netwib_constbuf *ppathname)
   netwib_err ret;
 
   /* obtain parent */
-  netwib_er(netwib_buf_init_ext_arrayempty(parentarray, sizeof(parentarray),
-                                           &parent));
-  parent.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(parentarray, &parent));
   ret = netwib_path_decode_parent(ppathname, &parent);
   if (ret == NETWIB_ERR_PAPATHCANTINIT) {
     /* can't go up */
@@ -101,13 +98,11 @@ netwib_err netwib_priv_dir_create_parents(netwib_constbuf *ppathname)
   }
 
   /* check if begin directory exists */
-  netwib_er(netwib_buf_init_ext_arrayempty(startarray, sizeof(startarray),
-                                           &start));
-  start.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storagearraysizeof(startarray, &start));
   netwib_er(netwib_path_decode_begin(&parent, &start));
   netwib_er(netwib_dirname_exists(&start, &yes));
   if ( !yes ) {
-    netwib_er(netwib_priv_errmsg_text("cannot create this dir: "));
+    netwib_er(netwib_priv_errmsg_string("cannot create this dir: "));
     netwib_er(netwib_priv_errmsg_append_buf(&start));
     netwib_er(netwib_buf_close(&start));
     netwib_er(netwib_buf_close(&parent));
