@@ -1,4 +1,4 @@
-/* This file is part of Netwib.
+/* This file is part of Netwib. Read and honor its license.
 */
 
 /*-------------------------------------------------------------*/
@@ -152,7 +152,7 @@ static netwib_err netwib_priv_err_text(netwib_err error,
     *pc = "file is not regular";
     break;
   case NETWIB_ERR_PAINDEXNODATA:
-    *pc = "index does not point to data (i.e. is just rewinded)";
+    *pc = "index does not point to data (index is just rewinded, or item was deleted)";
     break;
   case NETWIB_ERR_PATOOBIGFORHDR:
     *pc = "a parameter is too big to go in the physical header";
@@ -241,6 +241,9 @@ static netwib_err netwib_priv_err_text(netwib_err error,
   /* functions */
   case NETWIB_ERR_FUACCEPT: *pcfu = "accept"; break;
   case NETWIB_ERR_FUBIND: *pcfu = "bind"; break;
+  case NETWIB_ERR_FUCHDIR: *pcfu = "chdir"; break;
+  case NETWIB_ERR_FUCHMOD: *pcfu = "chmod"; break;
+  case NETWIB_ERR_FUCHOWN: *pcfu = "chown"; break;
   case NETWIB_ERR_FUCLOCKGETTIME: *pcfu = "chsize"; break;
   case NETWIB_ERR_FUCLOSEDIR: *pcfu = "closedir"; break;
   case NETWIB_ERR_FUCLOSEHANDLE: *pcfu = "CloseHandle"; break;
@@ -281,11 +284,12 @@ static netwib_err netwib_priv_err_text(netwib_err error,
   case NETWIB_ERR_FUGETPROCADDRESS: *pcfu = "GetProcAddress"; break;
   case NETWIB_ERR_FUGETRLIMIT: *pcfu = "getrlimit"; break;
   case NETWIB_ERR_FUGETPWNAMR: *pcfu = "getpwnam_r"; break;
+  case NETWIB_ERR_FUGETPWUID: *pcfu = "getpwuid"; break;
   case NETWIB_ERR_FUGETSOCKNAME: *pcfu = "getsockname"; break;
   case NETWIB_ERR_FUGETTIMEOFDAY: *pcfu = "gettimeofday"; break;
+  case NETWIB_ERR_FUGETUID: *pcfu = "getuid"; break;
   case NETWIB_ERR_FUGLOBALALLOC: *pcfu = "GlobalAlloc"; break;
   case NETWIB_ERR_FUGLOBALFREE: *pcfu = "GlobalFree"; break;
-  case NETWIB_ERR_FULOCALTIMER: *pcfu = "localtime_r"; break;
   case NETWIB_ERR_FUIOCTL: *pcfu = "ioctl"; break;
   case NETWIB_ERR_FUKILL: *pcfu = "kill"; break;
   case NETWIB_ERR_FULIBNETINIT: *pcfu = "libnet_init"; break;
@@ -299,15 +303,17 @@ static netwib_err netwib_priv_err_text(netwib_err error,
   case NETWIB_ERR_FULIBNETWRITERAWIPV6: *pcfu = "libnet_write_raw_ipv6"; break;
   case NETWIB_ERR_FULISTEN: *pcfu = "listen"; break;
   case NETWIB_ERR_FULOADLIBRARY: *pcfu = "LoadLibrary"; break;
+  case NETWIB_ERR_FULOCALTIMER: *pcfu = "localtime_r"; break;
   case NETWIB_ERR_FULSEEK: *pcfu = "lseek"; break;
   case NETWIB_ERR_FULSTAT: *pcfu = "lstat"; break;
   case NETWIB_ERR_FUMALLOC: *pcfu = "malloc"; break;
   case NETWIB_ERR_FUMKDIR: *pcfu = "mkdir"; break;
   case NETWIB_ERR_FUMPROTECT: *pcfu = "mprotect"; break;
   case NETWIB_ERR_FUNANOSLEEP: *pcfu = "nanosleep"; break;
-  case NETWIB_ERR_FUOPENDIR: *pcfu = "opendir"; break;
   case NETWIB_ERR_FUOPEN: *pcfu = "open"; break;
+  case NETWIB_ERR_FUOPENDIR: *pcfu = "opendir"; break;
   case NETWIB_ERR_FUOPENPROCESS: *pcfu = "OpenProcess"; break;
+  case NETWIB_ERR_FUOPENPTY: *pcfu = "openpty"; break;
   case NETWIB_ERR_FUPACKETALLOCATEPACKET: *pcfu = "PacketAllocatePacket"; break;
   case NETWIB_ERR_FUPACKETGETNETTYPE: *pcfu = "PacketGetNetType"; break;
   case NETWIB_ERR_FUPACKETOPENADAPTER: *pcfu = "PacketOpenAdapter"; break;
@@ -377,6 +383,10 @@ static netwib_err netwib_priv_err_text(netwib_err error,
   case NETWIB_ERR_FUSEND: *pcfu = "send"; break;
   case NETWIB_ERR_FUSENDTO: *pcfu = "sendto"; break;
   case NETWIB_ERR_FUSETEVENT: *pcfu = "SetEvent"; break;
+  case NETWIB_ERR_FUSETGID: *pcfu = "setgid"; break;
+  case NETWIB_ERR_FUSETGROUPS: *pcfu = "setgroups"; break;
+  case NETWIB_ERR_FUSETSID: *pcfu = "setsid"; break;
+  case NETWIB_ERR_FUSETUID: *pcfu = "setuid"; break;
   case NETWIB_ERR_FUSETSOCKOPT: *pcfu = "setsockopt"; break;
   case NETWIB_ERR_FUSIGNAL: *pcfu = "signal"; break;
   case NETWIB_ERR_FUSNMPEXTENSIONINIT: *pcfu = "SnmpExtensionInit"; break;
@@ -414,8 +424,8 @@ static netwib_err netwib_priv_err_append_herrno(netwib_uint32 varherrno,
 
 #if defined NETWIBDEF_SYSNAME_Unix
  #if NETWIBDEF_HAVEFUNC_HSTRERROR==1
-  netwib_er(netwib_buf_append_text(" = ", pbuf));
-  netwib_er(netwib_buf_append_text(hstrerror(varherrno), pbuf));
+  netwib_er(netwib_buf_append_string(" = ", pbuf));
+  netwib_er(netwib_buf_append_string(hstrerror(varherrno), pbuf));
  #endif
 #elif defined NETWIBDEF_SYSNAME_Windows
   /* there is no portable way to get Winsock error messages,
@@ -579,15 +589,15 @@ static netwib_err netwib_priv_err_append_herrno(netwib_uint32 varherrno,
         break;
     }
     if (pc != NULL) {
-      netwib_er(netwib_buf_append_text(" = ", pbuf));
-      netwib_er(netwib_buf_append_text(pc, pbuf));
+      netwib_er(netwib_buf_append_string(" = ", pbuf));
+      netwib_er(netwib_buf_append_string(pc, pbuf));
     }
   }
 #else
 #error "Unknown value for NETWIBDEF_SYSNAME"
 #endif
 
-  netwib_er(netwib_buf_append_text("\n", pbuf));
+  netwib_er(netwib_buf_append_string("\n", pbuf));
 
   return(NETWIB_ERR_OK);
 }
@@ -624,9 +634,9 @@ static netwib_err netwib_priv_err_append_err2(netwib_buf *pbuf)
 
   netwib_er(netwib_buf_ref_string(&(ptr->errmsg), &pc));
   if (pc[0] != '\0') {
-    netwib_er(netwib_buf_append_text(" hint: ", pbuf));
-    netwib_er(netwib_buf_append_text(pc, pbuf));
-    netwib_er(netwib_buf_append_text("\n", pbuf));
+    netwib_er(netwib_buf_append_string(" hint: ", pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
+    netwib_er(netwib_buf_append_string("\n", pbuf));
   }
 
   return(NETWIB_ERR_OK);
@@ -652,21 +662,21 @@ netwib_err netwib_priv_err_append_err(netwib_err error,
   netwib_er(netwib_priv_err_text(error, &perrstr, &perrstrfu));
   if (perrstr == NULL) {
     if (perrstrfu == NULL) {
-      netwib_er(netwib_buf_append_text("unknown error", pbuf));
+      netwib_er(netwib_buf_append_string("unknown error", pbuf));
     } else {
-      netwib_er(netwib_buf_append_text("error in ", pbuf));
-      netwib_er(netwib_buf_append_text(perrstrfu, pbuf));
-      netwib_er(netwib_buf_append_text("()", pbuf));
+      netwib_er(netwib_buf_append_string("error in ", pbuf));
+      netwib_er(netwib_buf_append_string(perrstrfu, pbuf));
+      netwib_er(netwib_buf_append_string("()", pbuf));
     }
   } else {
-    netwib_er(netwib_buf_append_text(perrstr, pbuf));
+    netwib_er(netwib_buf_append_string(perrstr, pbuf));
   }
 
   if (encodetype != NETWIB_ERR_ENCODETYPE_FULL) {
     /* stop here */
     return(NETWIB_ERR_OK);
   }
-  netwib_er(netwib_buf_append_text("\n", pbuf));
+  netwib_er(netwib_buf_append_string("\n", pbuf));
 
   /* errno */
   if (varerrno) {
@@ -692,12 +702,12 @@ netwib_err netwib_priv_err_append_err(netwib_err error,
                             MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
                             (LPTSTR) & lpMsgBuf, 0, NULL);
     if (bytenum) {
-      netwib_er(netwib_buf_append_text(" = ", pbuf));
-      netwib_er(netwib_buf_append_text((char *)lpMsgBuf, pbuf));
+      netwib_er(netwib_buf_append_string(" = ", pbuf));
+      netwib_er(netwib_buf_append_string((char *)lpMsgBuf, pbuf));
       /* use LocalFree, because it's not allocated in netwib */
       LocalFree(lpMsgBuf);
     } else {
-      netwib_er(netwib_buf_append_text("\n", pbuf));
+      netwib_er(netwib_buf_append_string("\n", pbuf));
     }
   }
 #else
@@ -724,11 +734,11 @@ netwib_err netwib_priv_err_append_err(netwib_err error,
 #if NETWIB_DEBUG_ERROR_BT==1
   if (error != NETWIB_ERR_OK) {
     netwib_string str;
-    netwib_er(netwib_debug_backtrace_str(&str));
-    netwib_er(netwib_buf_append_text(" backtrace: ", pbuf));
-    netwib_er(netwib_buf_append_text(str, pbuf));
-    netwib_er(netwib_buf_append_text("\n", pbuf));
-    netwib_er(netwib_debug_str_close(&str));
+    netwib_er(netwib_debug_backtrace_string(&str));
+    netwib_er(netwib_buf_append_string(" backtrace: ", pbuf));
+    netwib_er(netwib_buf_append_string(str, pbuf));
+    netwib_er(netwib_buf_append_string("\n", pbuf));
+    netwib_er(netwib_debug_string_close(&str));
   }
 #endif
 
