@@ -252,6 +252,15 @@ static netwib_err netwib_priv_fd_wait_select(int fd,
   struct timeval to, *pto;
   int reti;
 
+#if defined FD_SETSIZE
+ #if ! defined NETWIBDEF_SYSNAME_Windows
+  /* sous Windows, FD_SETSIZE vaut 64, mais fd peut le dpasser sans souci */
+  if (fd > FD_SETSIZE) {
+    return(NETWIB_ERR_PATOOHIGH);
+  }
+ #endif
+#endif
+
   /* initialize fd */
   FD_ZERO(&readfdset);
   FD_ZERO(&writefdset);
