@@ -1,14 +1,11 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -687,7 +684,7 @@ netwib_err netwib_io_init_record(netwib_constbuf *precordname,
                                  netwib_record_encodetype encodetype,
                                  netwib_io **ppio)
 {
-  netwib_bool rdinit, wrinit;
+  netwib_bool rdinit=NETWIB_FALSE, wrinit=NETWIB_FALSE;
   netwib_ptr pcommon;
   netwib_err ret;
 
