@@ -1,14 +1,11 @@
 /*
                                   NETWIB
                              Network library
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -469,6 +466,18 @@ netwib_err netwib_time_cmp(netwib_consttime *ptime1,
     } else {
       cmp = NETWIB_CMP_GT;
     }
+  } else if (ptime2 == NETWIB_TIME_ZERO) {
+    if (ptime1 == NETWIB_TIME_ZERO) {
+      cmp = NETWIB_CMP_EQ;
+    } else {
+      cmp = NETWIB_CMP_GT;
+    }
+  } else if (ptime2 == NETWIB_TIME_INFINITE) {
+    if (ptime1 == NETWIB_TIME_INFINITE) {
+      cmp = NETWIB_CMP_EQ;
+    } else {
+      cmp = NETWIB_CMP_LT;
+    }
   } else {
     if (ptime1->sec < ptime2->sec) {
       cmp = NETWIB_CMP_LT;
@@ -594,7 +603,7 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
       case NETWIB_TIME_ENCODETYPE_USEC2 :
       case NETWIB_TIME_ENCODETYPE_NSEC :
       case NETWIB_TIME_ENCODETYPE_NSEC2 :
-        netwib_er(netwib_buf_append_text("infinite", pbuf));
+        netwib_er(netwib_buf_append_string("infinite", pbuf));
         break;
       default :
         return(NETWIB_ERR_PAINVALIDTYPE);
@@ -621,7 +630,7 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
         if (encodetype == NETWIB_TIME_ENCODETYPE_BEST) {
           netwib_er(netwib_buf_append_byte('d', pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(" day", pbuf));
+          netwib_er(netwib_buf_append_string(" day", pbuf));
           if (xday != 1) {
             netwib_er(netwib_buf_append_byte('s', pbuf));
           }
@@ -640,7 +649,7 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
         if (encodetype == NETWIB_TIME_ENCODETYPE_BEST) {
           netwib_er(netwib_buf_append_byte('m', pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(" minute", pbuf));
+          netwib_er(netwib_buf_append_string(" minute", pbuf));
           if (xmin != 1) {
             netwib_er(netwib_buf_append_byte('s', pbuf));
           }
@@ -659,7 +668,7 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
         if (encodetype == NETWIB_TIME_ENCODETYPE_BEST) {
           netwib_er(netwib_buf_append_byte('h', pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(" hour", pbuf));
+          netwib_er(netwib_buf_append_string(" hour", pbuf));
           if (xhour != 1) {
             netwib_er(netwib_buf_append_byte('s', pbuf));
           }
@@ -678,7 +687,7 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
         if (encodetype == NETWIB_TIME_ENCODETYPE_BEST) {
           netwib_er(netwib_buf_append_byte('s', pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(" second", pbuf));
+          netwib_er(netwib_buf_append_string(" second", pbuf));
           if (sec != 1) {
             netwib_er(netwib_buf_append_byte('s', pbuf));
           }
@@ -695,9 +704,9 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
         }
         netwib_er(netwib_buf_append_fmt(pbuf, "%{uint32}", msec));
         if (encodetype == NETWIB_TIME_ENCODETYPE_BEST) {
-          netwib_er(netwib_buf_append_text("ms", pbuf));
+          netwib_er(netwib_buf_append_string("ms", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(" millisecond", pbuf));
+          netwib_er(netwib_buf_append_string(" millisecond", pbuf));
           if (sec != 1) {
             netwib_er(netwib_buf_append_byte('s', pbuf));
           }
@@ -714,9 +723,9 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
         }
         netwib_er(netwib_buf_append_fmt(pbuf, "%{uint32}", usec));
         if (encodetype == NETWIB_TIME_ENCODETYPE_BEST) {
-          netwib_er(netwib_buf_append_text("us", pbuf));
+          netwib_er(netwib_buf_append_string("us", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(" microsecond", pbuf));
+          netwib_er(netwib_buf_append_string(" microsecond", pbuf));
           if (usec != 1) {
             netwib_er(netwib_buf_append_byte('s', pbuf));
           }
@@ -733,9 +742,9 @@ static netwib_err netwib_buf_append_time2(netwib_consttime *preltime,
         }
         netwib_er(netwib_buf_append_fmt(pbuf, "%{uint32}", nsec));
         if (encodetype == NETWIB_TIME_ENCODETYPE_BEST) {
-          netwib_er(netwib_buf_append_text("ns", pbuf));
+          netwib_er(netwib_buf_append_string("ns", pbuf));
         } else {
-          netwib_er(netwib_buf_append_text(" nanosecond", pbuf));
+          netwib_er(netwib_buf_append_string(" nanosecond", pbuf));
           if (nsec != 1) {
             netwib_er(netwib_buf_append_byte('s', pbuf));
           }
@@ -994,7 +1003,7 @@ netwib_err netwib_buf_append_localtime(netwib_constlocaltime *plocaltime,
     case 12: pc = "Dec"; break;
     default: pc = "???"; break;
     }
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
     break;
   case NETWIB_LOCALTIME_ENCODETYPE_MON_LONG :
     switch(plocaltime->mon) {
@@ -1012,7 +1021,7 @@ netwib_err netwib_buf_append_localtime(netwib_constlocaltime *plocaltime,
     case 12: pc = "December"; break;
     default: pc = "???"; break;
     }
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
     break;
   case NETWIB_LOCALTIME_ENCODETYPE_YEAR_SHORT :
     ui = plocaltime->year / 100;
@@ -1033,7 +1042,7 @@ netwib_err netwib_buf_append_localtime(netwib_constlocaltime *plocaltime,
     case 6: pc = "Sat"; break;
     default: pc = "???"; break;
     }
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
     break;
   case NETWIB_LOCALTIME_ENCODETYPE_WDAY_LONG :
     switch(plocaltime->wday) {
@@ -1046,7 +1055,7 @@ netwib_err netwib_buf_append_localtime(netwib_constlocaltime *plocaltime,
     case 6: pc = "Saturday"; break;
     default: pc = "???"; break;
     }
-    netwib_er(netwib_buf_append_text(pc, pbuf));
+    netwib_er(netwib_buf_append_string(pc, pbuf));
     break;
   case NETWIB_LOCALTIME_ENCODETYPE_YDAY_ZERO :
     netwib_er(netwib_buf_append_fmt(pbuf, "%{r03;uint32}", plocaltime->yday));
@@ -1060,7 +1069,7 @@ netwib_err netwib_buf_append_localtime(netwib_constlocaltime *plocaltime,
     break;
   case NETWIB_LOCALTIME_ENCODETYPE_ZONE_GMT :
     i = plocaltime->zoneoffset / 3600;
-    netwib_er(netwib_buf_append_text("GMT", pbuf));
+    netwib_er(netwib_buf_append_string("GMT", pbuf));
     if (i != 0) {
       netwib_er(netwib_buf_append_fmt(pbuf, "%{int32:+}", i));
     }
@@ -1068,9 +1077,9 @@ netwib_err netwib_buf_append_localtime(netwib_constlocaltime *plocaltime,
   case NETWIB_LOCALTIME_ENCODETYPE_ZONE_HM :
     ui = (netwib_uint32) plocaltime->zoneoffset;
     if (plocaltime->zoneoffset >= 0) {
-      netwib_er(netwib_buf_append_text("+", pbuf));
+      netwib_er(netwib_buf_append_string("+", pbuf));
     } else {
-      netwib_er(netwib_buf_append_text("-", pbuf));
+      netwib_er(netwib_buf_append_string("-", pbuf));
       ui = (netwib_uint32) - plocaltime->zoneoffset;
     }
     netwib_er(netwib_buf_append_fmt(pbuf, "%{r02;uint32}", ui/3600));
