@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -553,7 +550,7 @@ static netwib_err netwox_priv_ripemd_test(netwox_ripemdversion ripemdversion,
 {
   netwib_buf buf, md;
 
-  netwib_er(netwib_buf_init_ext_text(data, &buf));
+  netwib_er(netwib_buf_init_ext_string(data, &buf));
   netwib_er(netwib_buf_init_mallocdefault(&md));
   netwib_er(netwox_ripemd_compute(ripemdversion, &buf, &md));
   netwib_er(netwox_buf_check_strmixed(&md, mdwanted));
