@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -112,19 +109,19 @@ static netwib_err netwox_priv_sha224256_update64(netwox_sha224256_context *pcont
     w[i] = in[i];
   }
 
-#define SHA_S0(x) (netwib_c2_uint32_ror ((x), 7) ^ netwib_c2_uint32_ror ((x), 18) ^ ((x) >> 3))
-#define SHA_S1(x) (netwib_c2_uint32_ror ((x), 17) ^ netwib_c2_uint32_ror ((x), 19) ^ ((x) >> 10))
+#define SHA2x_S0(x) (netwib_c2_uint32_ror ((x), 7) ^ netwib_c2_uint32_ror ((x), 18) ^ ((x) >> 3))
+#define SHA2x_S1(x) (netwib_c2_uint32_ror ((x), 17) ^ netwib_c2_uint32_ror ((x), 19) ^ ((x) >> 10))
   for (; i < 64; i++) {
-    w[i] = SHA_S1(w[i-2]) + w[i-7] + SHA_S0(w[i-15]) + w[i-16];
+    w[i] = SHA2x_S1(w[i-2]) + w[i-7] + SHA2x_S0(w[i-15]) + w[i-16];
   }
 
-#define SHA_Ch(x,y,z) (z ^ (x & (y ^ z)))
-#define SHA_Maj(x,y,z) ((x & y) | (z & (x|y)))
-#define SHA_Sum0(x) (netwib_c2_uint32_ror ((x), 2) ^ netwib_c2_uint32_ror ((x), 13) ^ netwib_c2_uint32_ror ((x), 22))
-#define SHA_Sum1(x) (netwib_c2_uint32_ror ((x), 6) ^ netwib_c2_uint32_ror ((x), 11) ^ netwib_c2_uint32_ror ((x), 25))
+#define SHA2x_Ch(x,y,z) (z ^ (x & (y ^ z)))
+#define SHA2x_Maj(x,y,z) ((x & y) | (z & (x|y)))
+#define SHA2x_Sum0(x) (netwib_c2_uint32_ror ((x), 2) ^ netwib_c2_uint32_ror ((x), 13) ^ netwib_c2_uint32_ror ((x), 22))
+#define SHA2x_Sum1(x) (netwib_c2_uint32_ror ((x), 6) ^ netwib_c2_uint32_ror ((x), 11) ^ netwib_c2_uint32_ror ((x), 25))
   for (i = 0; i < 64; i++) {
-    t1 = (h) + SHA_Sum1((e)) + SHA_Ch((e),(f),(g)) + K[i] + w[i];
-    t2 = SHA_Sum0((a)) + SHA_Maj((a),(b),(c));
+    t1 = (h) + SHA2x_Sum1((e)) + SHA2x_Ch((e),(f),(g)) + K[i] + w[i];
+    t2 = SHA2x_Sum0((a)) + SHA2x_Maj((a),(b),(c));
     h = g;
     g = f;
     f = e;
