@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -175,29 +172,29 @@ static netwib_err netwox_priv_sha384512_update128(netwox_sha384512_context *pcon
     netwib__data_decode_uint64(data, w[i]);
   }
 
-#define SHA_S0(x,r) { netwib__uint64_ror((x), 1, L_tmp1); netwib__uint64_ror((x), 8, L_tmp2); netwib__uint64_shr((x), 7, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
-#define SHA_S1(x,r) { netwib__uint64_ror((x), 19, L_tmp1); netwib__uint64_ror((x), 61, L_tmp2); netwib__uint64_shr((x), 6, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
+#define SHA3x_S0(x,r) { netwib__uint64_ror((x), 1, L_tmp1); netwib__uint64_ror((x), 8, L_tmp2); netwib__uint64_shr((x), 7, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
+#define SHA3x_S1(x,r) { netwib__uint64_ror((x), 19, L_tmp1); netwib__uint64_ror((x), 61, L_tmp2); netwib__uint64_shr((x), 6, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
   for (i = 16; i < 80; i++) {
-    SHA_S1(w[i - 2], F_tmp1);
-    SHA_S0(w[i - 15], F_tmp2);
+    SHA3x_S1(w[i - 2], F_tmp1);
+    SHA3x_S0(w[i - 15], F_tmp2);
     netwib__uint64_add(F_tmp1, F_tmp2, F_tmp3);
     netwib__uint64_add(F_tmp3, w[i - 7], F_tmp3);
     netwib__uint64_add(F_tmp3, w[i - 16], w[i]);
   }
 
-#define SHA_Sum0(x,r) { netwib__uint64_ror((x), 28, L_tmp1); netwib__uint64_ror((x), 34, L_tmp2); netwib__uint64_ror((x), 39, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
-#define SHA_Sum1(x,r) { netwib__uint64_ror((x), 14, L_tmp1); netwib__uint64_ror((x), 18, L_tmp2); netwib__uint64_ror((x), 41, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
-#define SHA_Ch(x,y,z,r) { netwib__uint64_and((x), (y), L_tmp1); netwib__uint64_not((x), L_tmp2); netwib__uint64_and(L_tmp2, (z), L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp3, r); }
-#define SHA_Maj(x,y,z,r) { netwib__uint64_and((x), (y), L_tmp1); netwib__uint64_and((x), (z), L_tmp2); netwib__uint64_xor(L_tmp1, L_tmp2, L_tmp1); netwib__uint64_and((y), (z), L_tmp2); netwib__uint64_xor(L_tmp1, L_tmp2, r); }
+#define SHA3x_Sum0(x,r) { netwib__uint64_ror((x), 28, L_tmp1); netwib__uint64_ror((x), 34, L_tmp2); netwib__uint64_ror((x), 39, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
+#define SHA3x_Sum1(x,r) { netwib__uint64_ror((x), 14, L_tmp1); netwib__uint64_ror((x), 18, L_tmp2); netwib__uint64_ror((x), 41, L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp2, r); netwib__uint64_xor(r, L_tmp3, r); }
+#define SHA3x_Ch(x,y,z,r) { netwib__uint64_and((x), (y), L_tmp1); netwib__uint64_not((x), L_tmp2); netwib__uint64_and(L_tmp2, (z), L_tmp3); netwib__uint64_xor(L_tmp1, L_tmp3, r); }
+#define SHA3x_Maj(x,y,z,r) { netwib__uint64_and((x), (y), L_tmp1); netwib__uint64_and((x), (z), L_tmp2); netwib__uint64_xor(L_tmp1, L_tmp2, L_tmp1); netwib__uint64_and((y), (z), L_tmp2); netwib__uint64_xor(L_tmp1, L_tmp2, r); }
   for (i = 0; i < 80; i++) {
-    SHA_Sum1(e, F_tmp1);
-    SHA_Ch(e, f, g, F_tmp2);
+    SHA3x_Sum1(e, F_tmp1);
+    SHA3x_Ch(e, f, g, F_tmp2);
     netwib__uint64_add(F_tmp1, F_tmp2, F_tmp3);
     netwib__uint64_add(F_tmp3, h, F_tmp3);
     netwib__uint64_add(F_tmp3, k[i], F_tmp3);
     netwib__uint64_add(F_tmp3, w[i], t1);
-    SHA_Sum0(a, F_tmp1);
-    SHA_Maj(a, b, c, F_tmp2);
+    SHA3x_Sum0(a, F_tmp1);
+    SHA3x_Maj(a, b, c, F_tmp2);
     netwib__uint64_add(F_tmp1, F_tmp2, t2);
     h = g;
     g = f;
