@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -35,30 +32,23 @@ netwib_err netwox_httpserreqhdrs_init(netwox_httpserreqhdrs *phdrs)
   netwib_er(netwib_buf_init_mallocdefault(&phdrs->uri));
 
   phdrs->hostset = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->hosthost));
-  phdrs->hosthost.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->hosthost));
 
   phdrs->authbasicset = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->authbasiclogin));
-  phdrs->authbasiclogin.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->authbasicpassword));
-  phdrs->authbasicpassword.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->authbasiclogin));
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->authbasicpassword));
 
   phdrs->proxyauthbasicset = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->proxyauthbasiclogin));
-  phdrs->proxyauthbasiclogin.flags |= NETWIB_BUF_FLAGS_CANALLOC;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->proxyauthbasicpassword));
-  phdrs->proxyauthbasicpassword.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->proxyauthbasiclogin));
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->proxyauthbasicpassword));
 
   phdrs->useragentset = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->useragent));
-  phdrs->useragent.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->useragent));
 
   phdrs->contentlengthset = NETWIB_FALSE;
 
   phdrs->saveallheaders = NETWIB_FALSE;
-  netwib_er(netwib_buf_init_ext_empty(&phdrs->allheaders));
-  phdrs->allheaders.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&phdrs->allheaders));
 
   return(NETWIB_ERR_OK);
 }
@@ -248,7 +238,7 @@ netwib_err netwox_httpserreqhdrs_decode(netwox_httpserctx *pctx,
     /* eventually save all headers */
     if (phdrs->saveallheaders) {
       netwib_er(netwib_buf_append_buf(pbuf, &phdrs->allheaders));
-      netwib_er(netwib_buf_append_text("\r\n", &phdrs->allheaders));
+      netwib_er(netwib_buf_append_string("\r\n", &phdrs->allheaders));
     }
   }
   netwib_er(netwib_bufpool_buf_close(pctx->pbufpool, &pbuf));
