@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -34,8 +31,7 @@ netwib_err netwox_identserver_init(netwox_identserver *pidentserver)
 {
   /* those can be changed by users */
   pidentserver->timeoutms = 60000;
-  netwib_er(netwib_buf_init_ext_empty(&pidentserver->username));
-  pidentserver->username.flags |= NETWIB_BUF_FLAGS_CANALLOC;
+  netwib_er(netwib_buf_init_ext_storage(&pidentserver->username));
   pidentserver->pallowedclients = NULL;
 
   /* internal */
@@ -93,7 +89,7 @@ static netwib_err netwox_identserver_session2(netwox_priv_identserver *pident)
       netwib_er(netwib_buf_append_fmt(pline, ":USERID:UNIX:%{buf}\r\n",
                                       &pident->pcommon->username));
     } else {
-      netwib_er(netwib_buf_append_text(":ERROR:HIDDEN-USER\r\n", pline));
+      netwib_er(netwib_buf_append_string(":ERROR:HIDDEN-USER\r\n", pline));
     }
     ret = netwib_io_write(pident->pio, pline);
   }
