@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -234,12 +231,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_PARAMETER_12, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_PARAMETER_12, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -262,12 +259,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -291,12 +288,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -319,12 +316,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -347,12 +344,12 @@ static netwib_err netwox_smbcmdtscq_encode_tsc_plm(const netwox_smbcmd_transacti
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_PARAMETER_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_PARAMETER_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
     netwib_er(netwox_smbcmdcmn_data_decodestr(&para, &parasize, NETWIB_FALSE, &descriptor));
-    netwib_er(netwib_buf_cmp_str(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_RETURN_1, &cmp));
+    netwib_er(netwib_buf_cmp_string(&descriptor, NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_RETURN_1, &cmp));
     if (cmp != NETWIB_CMP_EQ) {
       netwib_er(NETWIB_ERR_NOTCONVERTED);
     }
@@ -401,8 +398,8 @@ netwib_err netwox_smbcmdtscq_encode_smbcmd(netwox_constsmbcmd *psmbcmd,
   namesize = netwib__buf_ref_data_size(&psmbcmd->value.transaction_q.name);
 
   if (psmbcmd->value.transaction_q.isunicode) {
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buftocmp));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
+    netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buftocmp));
     netwib_er(netwox_buf_decode_ucs2le(&bufstr, &buftocmp));
     netwib_er(netwib_buf_cmp(&psmbcmd->value.transaction_q.name, &buftocmp,
                              &cmp));
@@ -410,9 +407,9 @@ netwib_err netwox_smbcmdtscq_encode_smbcmd(netwox_constsmbcmd *psmbcmd,
       netwib_er(netwox_smbcmdtscq_encode_tsc_plm(&psmbcmd->value.transaction_q, psmbcmdtscq));
       return(NETWIB_ERR_OK);
     }
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPE,
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPE,
                                        &bufstr));
-    netwib_er(netwib_buf_init_ext_arrayempty(array, sizeof(array), &buftocmp));
+    netwib_er(netwib_buf_init_ext_arraysizeofempty(array, &buftocmp));
     netwib_er(netwox_buf_decode_ucs2le(&bufstr, &buftocmp));
     netwib_er(netwib_buf_cmp(&psmbcmd->value.transaction_q.name, &buftocmp,
                              &cmp));
@@ -421,14 +418,14 @@ netwib_err netwox_smbcmdtscq_encode_smbcmd(netwox_constsmbcmd *psmbcmd,
       return(NETWIB_ERR_OK);
     }
   } else {
-    netwib_er(netwib_buf_cmp_str(&psmbcmd->value.transaction_q.name,
+    netwib_er(netwib_buf_cmp_string(&psmbcmd->value.transaction_q.name,
                                  NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN,
                                  &cmp));
     if (cmp == NETWIB_CMP_EQ) {
       netwib_er(netwox_smbcmdtscq_encode_tsc_plm(&psmbcmd->value.transaction_q, psmbcmdtscq));
       return(NETWIB_ERR_OK);
     }
-    netwib_er(netwib_buf_cmp_str(&psmbcmd->value.transaction_q.name,
+    netwib_er(netwib_buf_cmp_string(&psmbcmd->value.transaction_q.name,
                                  NETWOX_SMBCMD_TRANSACTION_NAME_PIPE,
                                  &cmp));
     if (cmp == NETWIB_CMP_EQ) {
@@ -453,17 +450,17 @@ netwib_err netwox_smbcmdtscq_decode_smbcmd(netwox_constsmbcmdtscq *psmbcmdtscq,
       return(NETWIB_ERR_NOTCONVERTED);
     }
     if (psmbcmd->value.transaction_q.isunicode) {
-      netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
+      netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
       netwib_er(netwox_buf_decode_ucs2le(&bufstr, &psmbcmd->value.transaction_q.name));
     } else {
-      netwib_er(netwib_buf_append_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
+      netwib_er(netwib_buf_append_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
     }
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 2, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSCQ_PLM_SUBCMD_NETSHAREENUM);
     psmbcmd->value.transaction_q.para.endoffset += 2;
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_PARAMETER_12, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_PARAMETER_12, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_RETURN_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSHAREENUM_DESCRIPTOR_RETURN_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 4, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSC_NETSHAREENUM_FMT_1);
@@ -477,17 +474,17 @@ netwib_err netwox_smbcmdtscq_decode_smbcmd(netwox_constsmbcmdtscq *psmbcmdtscq,
       return(NETWIB_ERR_NOTCONVERTED);
     }
     if (psmbcmd->value.transaction_q.isunicode) {
-      netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
+      netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
       netwib_er(netwox_buf_decode_ucs2le(&bufstr, &psmbcmd->value.transaction_q.name));
     } else {
-      netwib_er(netwib_buf_append_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
+      netwib_er(netwib_buf_append_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
     }
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 2, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSCQ_PLM_SUBCMD_NETSHAREGETINFO);
     psmbcmd->value.transaction_q.para.endoffset += 2;
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_PARAMETER_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_PARAMETER_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_RETURN_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSHAREGETINFO_DESCRIPTOR_RETURN_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&psmbcmdtscq->value.netsharegetinfo.share, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 4, &para));
@@ -502,17 +499,17 @@ netwib_err netwox_smbcmdtscq_decode_smbcmd(netwox_constsmbcmdtscq *psmbcmdtscq,
       return(NETWIB_ERR_NOTCONVERTED);
     }
     if (psmbcmd->value.transaction_q.isunicode) {
-      netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
+      netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
       netwib_er(netwox_buf_decode_ucs2le(&bufstr, &psmbcmd->value.transaction_q.name));
     } else {
-      netwib_er(netwib_buf_append_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
+      netwib_er(netwib_buf_append_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
     }
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 2, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSCQ_PLM_SUBCMD_NETSERVERGETINFO);
     psmbcmd->value.transaction_q.para.endoffset += 2;
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_PARAMETER_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_PARAMETER_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_RETURN_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSERVERGETINFO_DESCRIPTOR_RETURN_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 4, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSC_NETSERVERGETINFO_FMT_1);
@@ -526,17 +523,17 @@ netwib_err netwox_smbcmdtscq_decode_smbcmd(netwox_constsmbcmdtscq *psmbcmdtscq,
       return(NETWIB_ERR_NOTCONVERTED);
     }
     if (psmbcmd->value.transaction_q.isunicode) {
-      netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
+      netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
       netwib_er(netwox_buf_decode_ucs2le(&bufstr, &psmbcmd->value.transaction_q.name));
     } else {
-      netwib_er(netwib_buf_append_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
+      netwib_er(netwib_buf_append_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
     }
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 2, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSCQ_PLM_SUBCMD_NETWKSTAGETINFO);
     psmbcmd->value.transaction_q.para.endoffset += 2;
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_PARAMETER_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_PARAMETER_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_RETURN_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETWKSTAGETINFO_DESCRIPTOR_RETURN_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 4, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSC_NETWKSTAGETINFO_FMT_1);
@@ -550,17 +547,17 @@ netwib_err netwox_smbcmdtscq_decode_smbcmd(netwox_constsmbcmdtscq *psmbcmdtscq,
       return(NETWIB_ERR_NOTCONVERTED);
     }
     if (psmbcmd->value.transaction_q.isunicode) {
-      netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
+      netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &bufstr));
       netwib_er(netwox_buf_decode_ucs2le(&bufstr, &psmbcmd->value.transaction_q.name));
     } else {
-      netwib_er(netwib_buf_append_text(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
+      netwib_er(netwib_buf_append_string(NETWOX_SMBCMD_TRANSACTION_NAME_PIPELANMAN, &psmbcmd->value.transaction_q.name));
     }
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 2, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSCQ_PLM_SUBCMD_NETSERVERENUM2);
     psmbcmd->value.transaction_q.para.endoffset += 2;
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_PARAMETER_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_PARAMETER_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
-    netwib_er(netwib_buf_init_ext_text(NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_RETURN_1, &bufstr));
+    netwib_er(netwib_buf_init_ext_string(NETWOX_SMBCMDTSC_NETSERVERENUM2_DESCRIPTOR_RETURN_1, &bufstr));
     netwib_er(netwox_smbcmdcmn_data_appendstr(&bufstr, NETWIB_FALSE, &psmbcmd->value.transaction_q.para));
     netwib_er(netwib_buf_wantspace(&psmbcmd->value.transaction_q.para, 8, &para));
     netwib__data_append_uint16_le(para, NETWOX_SMBCMDTSC_NETSERVERENUM2_FMT_1);
