@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -44,6 +41,7 @@ netwox_toolarg t000078_args[] = {
   NETWOX_TOOLARG_OPT_BUF_DEVICE('d', NULL, NULL, NULL),
   NETWOX_TOOLARG_OPT_BUF_FILTER('f', NULL, NULL, NULL),
   NETWOX_TOOLARG_OPT_SPOOFIP('s', NULL, NULL, "linkbraw"),
+  NETWOX_TOOLARG_OPTA_IPS_SU('i', NULL, "limit the list of IP addresses to reset", NULL),
   NETWOX_TOOLARG_END
 };
 netwox_tooltreenodetype t000078_nodes[] = {
@@ -65,8 +63,10 @@ netwib_err t000078_core(int argc, char *argv[])
   netwib_io *psniffio, *pspoofio;
   netwib_spoof_ip_inittype inittype;
   netwib_buf pkt, filter, device;
+  netwib_ips *pips;
   netwib_iphdr ipheader, ipheader2;
   netwib_tcphdr tcpheader, tcpheader2;
+  netwib_bool ipsisset, yes;
   netwib_err ret;
 
   /* obtain parameters */
@@ -74,6 +74,8 @@ netwib_err t000078_core(int argc, char *argv[])
   netwib_er(netwox_arg_buf(parg, 'd', &device));
   netwib_er(netwox_arg_buf(parg, 'f', &filter));
   netwib_er(netwox_arg_spoofip(parg, 's', &inittype));
+  netwib_er(netwox_arg_isset(parg, 'i', &ipsisset));
+  netwib_er(netwox_arg_ips(parg, 'i', &pips));
 
   /* initialize io */
   netwib_er(netwib_io_init_spoof_ip(inittype, &pspoofio));
@@ -92,6 +94,16 @@ netwib_err t000078_core(int argc, char *argv[])
     ret = netwib_pkt_decode_iptcpdata(&pkt, &ipheader, &tcpheader, NULL);
     if (ret != NETWIB_ERR_OK) continue;
     if (tcpheader.rst || tcpheader.fin) continue;
+    /* if an ip range was specified, reset only if addresses are inside */
+    if (ipsisset) {
+      netwib_er(netwib_ips_contains_ip(pips, &ipheader.src, &yes));
+      if (!yes) {
+        netwib_er(netwib_ips_contains_ip(pips, &ipheader.dst, &yes));
+        if (!yes) {
+          continue;
+        }
+      }
+    }
     /* answer */
     netwib_er(netwib_iphdr_initdefault(ipheader.src.iptype, &ipheader2));
     ipheader2.src = ipheader.dst;
