@@ -1,14 +1,11 @@
 /*
                                   NETWOX
                              Network toolbox
-                Copyright(c) 1999-2006 Laurent Constantin
+                Copyright(c) 1999-2008 Laurent Constantin
                                   -----
 
-  Main server    : http://www.laurentconstantin.com/
-  Backup servers : http://go.to/laurentconstantin/
-                   http://laurentconstantin.est-la.com/
-                   http://laurentconstantin.free.fr/
-                   http://membres.lycos.fr/lauconstantin/
+  Main server   : http://www.laurentconstantin.com/
+  Backup server : http://laurentconstantin.free.fr/
   [my current email address is on the web servers]
 
                                   -----
@@ -609,7 +606,7 @@ netwib_err t000171_core(int argc, char *argv[])
   netwib_er(netwox_arg_buf(parg, 'd', &device));
   netwib_er(netwox_arg_eth(parg, 'e', &infos.clienteth));
   netwib_er(netwox_arg_uint32(parg, 'T', &infos.timeoutms));
-  netwib_er(netwib_buf_init_ext_text("udp and (port 67 or port 68)", &filter));
+  netwib_er(netwib_buf_init_ext_string("udp and (port 67 or port 68)", &filter));
   netwib_er(netwox_snispo_init_eth(&device, &filter, &infos.pio));
   netwib_er(netwib_bufpool_initdefault(&infos.pbufpool));
 
