@@ -3,21 +3,15 @@
 /*-------------------------------------------------------------*/
 static netwib_err test__netwib_c2_uint(void)
 {
-  netwib_uint64 ui64;
   char a;
   int b;
-  a = 0xDA;
-  b = 0xDCBADCBA;
+  a = (char)(unsigned char)0xDA;
+  b = (int)0xDCBADCBA;
 
   puts("++++----\nTest of function netwib_c2_uint");
 
   netwib_er(netwib_fmt_display("%{uint16:04X}\n", netwib_c2_uint16_2(a,a)));
   netwib_er(netwib_fmt_display("%{uint32:08X}\n", netwib_c2_uint32_4(a,a,a,a)));
-  netwib_c2_uint64_set_8(ui64,a,a,a,a,a,a,a,a);
-  netwib_er(netwib_fmt_display("%{uint64:16X}\n", ui64));
-  netwib_c2_uint64_set_32(ui64,b,b);
-  netwib_er(netwib_fmt_display("%{uint64:16X}\n", ui64));
-
   return(NETWIB_ERR_OK);
 }
 
